Data Fields

Here is a list of all struct and union fields with links to the structures/unions they belong to:

- dl_method : so3_parameters_t
- L : so3_parameters_t
- L0 : so3_parameters_t
- N : so3_parameters_t
- n_mode : so3_parameters_t
- n_order : so3_parameters_t
- reality : so3_parameters_t
- sampling_scheme : so3_parameters_t
- steerable : so3_parameters_t
- storage : so3_parameters_t
- verbosity : so3_parameters_t